@@ -64,10 +64,16 @@ class OGRCSVEditableLayerSynchronizer final
           m_papszOpenOptions(CSLDuplicate(papszOpenOptions))
     {
     }
-    virtual ~OGRCSVEditableLayerSynchronizer() GDAL_OVERRIDE;
+
+    virtual ~OGRCSVEditableLayerSynchronizer() override;
 
     virtual OGRErr EditableSyncToDisk(OGRLayer *poEditableLayer,
                                       OGRLayer **ppoDecoratedLayer) override;
+
+    std::vector<std::string> GetFileList()
+    {
+        return m_poCSVLayer->GetFileList();
+    }
 };
 
 /************************************************************************/
@@ -88,6 +94,7 @@ OGRErr OGRCSVEditableLayerSynchronizer::EditableSyncToDisk(
 {
     CPLAssert(m_poCSVLayer == *ppoDecoratedLayer);
 
+    GDALDataset *poDS = m_poCSVLayer->GetDataset();
     const CPLString osLayerName(m_poCSVLayer->GetName());
     const CPLString osFilename(m_poCSVLayer->GetFilename());
     const bool bCreateCSVT = m_poCSVLayer->GetCreateCSVT();
@@ -103,7 +110,7 @@ OGRErr OGRCSVEditableLayerSynchronizer::EditableSyncToDisk(
     }
     const char chDelimiter = m_poCSVLayer->GetDelimiter();
     OGRCSVLayer *poCSVTmpLayer = new OGRCSVLayer(
-        osLayerName, nullptr, -1, osTmpFilename, true, true, chDelimiter);
+        poDS, osLayerName, nullptr, -1, osTmpFilename, true, true, chDelimiter);
     poCSVTmpLayer->BuildFeatureDefn(nullptr, nullptr, m_papszOpenOptions);
     poCSVTmpLayer->SetCRLF(m_poCSVLayer->GetCRLF());
     poCSVTmpLayer->SetCreateCSVT(bCreateCSVT || bHasCSVT);
@@ -292,8 +299,8 @@ OGRErr OGRCSVEditableLayerSynchronizer::EditableSyncToDisk(
     }
 
     m_poCSVLayer =
-        new OGRCSVLayer(osLayerName, fp, -1, osFilename, false, /* new */
-                        true,                                   /* update */
+        new OGRCSVLayer(poDS, osLayerName, fp, -1, osFilename, false, /* new */
+                        true, /* update */
                         chDelimiter);
     m_poCSVLayer->BuildFeatureDefn(nullptr, nullptr, m_papszOpenOptions);
     *ppoDecoratedLayer = m_poCSVLayer;
@@ -305,14 +312,26 @@ OGRErr OGRCSVEditableLayerSynchronizer::EditableSyncToDisk(
 /*                        OGRCSVEditableLayer                           */
 /************************************************************************/
 
-class OGRCSVEditableLayer final : public OGREditableLayer
+class OGRCSVEditableLayer final : public IOGRCSVLayer, public OGREditableLayer
 {
     std::set<CPLString> m_oSetFields;
 
   public:
     OGRCSVEditableLayer(OGRCSVLayer *poCSVLayer, char **papszOpenOptions);
 
-    virtual OGRErr CreateField(OGRFieldDefn *poField,
+    OGRLayer *GetLayer() override
+    {
+        return this;
+    }
+
+    std::vector<std::string> GetFileList() override
+    {
+        return cpl::down_cast<OGRCSVEditableLayerSynchronizer *>(
+                   m_poSynchronizer)
+            ->GetFileList();
+    }
+
+    virtual OGRErr CreateField(const OGRFieldDefn *poField,
                                int bApproxOK = TRUE) override;
     virtual OGRErr DeleteField(int iField) override;
     virtual OGRErr AlterFieldDefn(int iField, OGRFieldDefn *poNewFieldDefn,
@@ -339,7 +358,8 @@ OGRCSVEditableLayer::OGRCSVEditableLayer(OGRCSVLayer *poCSVLayer,
 /*                            CreateField()                             */
 /************************************************************************/
 
-OGRErr OGRCSVEditableLayer::CreateField(OGRFieldDefn *poNewField, int bApproxOK)
+OGRErr OGRCSVEditableLayer::CreateField(const OGRFieldDefn *poNewField,
+                                        int bApproxOK)
 
 {
     if (m_poEditableFeatureDefn->GetFieldCount() >= 10000)
@@ -409,11 +429,7 @@ GIntBig OGRCSVEditableLayer::GetFeatureCount(int bForce)
 /*                          OGRCSVDataSource()                          */
 /************************************************************************/
 
-OGRCSVDataSource::OGRCSVDataSource()
-    : pszName(nullptr), papoLayers(nullptr), nLayers(0), bUpdate(false),
-      bEnableGeometryFields(false)
-{
-}
+OGRCSVDataSource::OGRCSVDataSource() = default;
 
 /************************************************************************/
 /*                         ~OGRCSVDataSource()                          */
@@ -422,9 +438,7 @@ OGRCSVDataSource::OGRCSVDataSource()
 OGRCSVDataSource::~OGRCSVDataSource()
 
 {
-    for (int i = 0; i < nLayers; i++)
-        delete papoLayers[i];
-    CPLFree(papoLayers);
+    m_apoLayers.clear();
 
     if (bUpdate)
         OGRCSVDriverRemoveFromMap(pszName, this);
@@ -464,10 +478,10 @@ int OGRCSVDataSource::TestCapability(const char *pszCap)
 OGRLayer *OGRCSVDataSource::GetLayer(int iLayer)
 
 {
-    if (iLayer < 0 || iLayer >= nLayers)
+    if (iLayer < 0 || iLayer >= static_cast<int>(m_apoLayers.size()))
         return nullptr;
 
-    return papoLayers[iLayer];
+    return m_apoLayers[iLayer]->GetLayer();
 }
 
 /************************************************************************/
@@ -485,6 +499,9 @@ CPLString OGRCSVDataSource::GetRealExtension(CPLString osFilename)
         else if (osFilename.size() > 7 &&
                  EQUAL(osFilename + osFilename.size() - 7, ".tsv.gz"))
             return "tsv";
+        else if (osFilename.size() > 7 &&
+                 EQUAL(osFilename + osFilename.size() - 7, ".psv.gz"))
+            return "psv";
     }
     return osExt;
 }
@@ -577,7 +594,8 @@ int OGRCSVDataSource::Open(const char *pszFilename, int bUpdateIn,
 
     // Is this a single CSV file?
     if (VSI_ISREG(sStatBuf.st_mode) &&
-        (bIgnoreExtension || EQUAL(osExt, "csv") || EQUAL(osExt, "tsv")))
+        (bIgnoreExtension || EQUAL(osExt, "csv") || EQUAL(osExt, "tsv") ||
+         EQUAL(osExt, "psv")))
     {
         if (EQUAL(CPLGetFilename(osFilename), "NfdcFacilities.xls"))
         {
@@ -589,7 +607,7 @@ int OGRCSVDataSource::Open(const char *pszFilename, int bUpdateIn,
             OpenTable(osFilename, papszOpenOptionsIn, "BaseEndDisplaced");
             OpenTable(osFilename, papszOpenOptionsIn, "ReciprocalEndPhysical");
             OpenTable(osFilename, papszOpenOptionsIn, "ReciprocalEndDisplaced");
-            return nLayers != 0;
+            return !m_apoLayers.empty();
         }
         else if (bUSGeonamesFile)
         {
@@ -613,7 +631,7 @@ int OGRCSVDataSource::Open(const char *pszFilename, int bUpdateIn,
                 OpenTable(osFilename, papszOpenOptionsIn, nullptr, "PRIM");
                 OpenTable(osFilename, papszOpenOptionsIn, nullptr, "SOURCE");
             }
-            return nLayers != 0;
+            return !m_apoLayers.empty();
         }
 
         return OpenTable(osFilename, papszOpenOptionsIn);
@@ -710,7 +728,7 @@ int OGRCSVDataSource::Open(const char *pszFilename, int bUpdateIn,
 
     // We presume that this is indeed intended to be a CSV
     // datasource if over half the files were .csv files.
-    return bForceOpen || nNotCSVCount < nLayers;
+    return bForceOpen || nNotCSVCount < GetLayerCount();
 }
 
 /************************************************************************/
@@ -739,8 +757,7 @@ bool OGRCSVDataSource::OpenTable(const char *pszFilename,
 
     if (!bUpdate && strstr(pszFilename, "/vsigzip/") == nullptr &&
         strstr(pszFilename, "/vsizip/") == nullptr)
-        fp = reinterpret_cast<VSILFILE *>(VSICreateBufferedReaderHandle(
-            reinterpret_cast<VSIVirtualHandle *>(fp)));
+        fp = VSICreateBufferedReaderHandle(fp);
 
     CPLString osLayerName = CPLGetBasename(pszFilename);
     CPLString osExt = CPLGetExtension(pszFilename);
@@ -758,6 +775,12 @@ bool OGRCSVDataSource::OpenTable(const char *pszFilename,
             osLayerName = osLayerName.substr(0, osLayerName.size() - 4);
             osExt = "tsv";
         }
+        else if (strlen(pszFilename) > 7 &&
+                 EQUAL(pszFilename + strlen(pszFilename) - 7, ".psv.gz"))
+        {
+            osLayerName = osLayerName.substr(0, osLayerName.size() - 4);
+            osExt = "psv";
+        }
     }
 
     int nMaxLineSize = atoi(CPLGetConfigOption(
@@ -771,7 +794,7 @@ bool OGRCSVDataSource::OpenTable(const char *pszFilename,
         nMaxLineSizeAsSize_t = static_cast<size_t>(-1);
     }
 
-    // Read and parse a line.  Did we get multiple fields?
+    // Read and parse a line to detect separator.
 
     std::string osLine;
     {
@@ -783,105 +806,82 @@ bool OGRCSVDataSource::OpenTable(const char *pszFilename,
         }
         osLine = pszLine;
     }
-    char chDelimiter = CSVDetectSeperator(osLine.c_str());
-    if (chDelimiter != '\t' && osLine.find('\t') != std::string::npos)
+
+    char chDelimiter = ',';
+    const char *pszDelimiter =
+        CSLFetchNameValueDef(papszOpenOptionsIn, "SEPARATOR", "AUTO");
+    if (EQUAL(pszDelimiter, "AUTO"))
     {
-        // Force the delimiter to be TAB for a .tsv file that has a tabulation
-        // in its first line */
-        if (EQUAL(osExt, "tsv"))
+        chDelimiter = CSVDetectSeperator(osLine.c_str());
+        if (chDelimiter != '\t' && osLine.find('\t') != std::string::npos)
         {
-            chDelimiter = '\t';
-        }
-        else
-        {
-            for (int nDontHonourStrings = 0; nDontHonourStrings <= 1;
-                 nDontHonourStrings++)
+            // Force the delimiter to be TAB for a .tsv file that has a tabulation
+            // in its first line */
+            if (EQUAL(osExt, "tsv"))
             {
-                const bool bHonourStrings = !CPL_TO_BOOL(nDontHonourStrings);
-                // Read the first 2 lines to see if they have the same number
-                // of fields, if using tabulation.
-                VSIRewindL(fp);
-                char **papszTokens = CSVReadParseLine3L(
-                    fp, nMaxLineSizeAsSize_t, "\t", bHonourStrings,
-                    false,  // bKeepLeadingAndClosingQuotes
-                    false,  // bMergeDelimiter
-                    true    // bSkipBOM
-                );
-                const int nTokens1 = CSLCount(papszTokens);
-                CSLDestroy(papszTokens);
-                papszTokens = CSVReadParseLine3L(
-                    fp, nMaxLineSizeAsSize_t, "\t", bHonourStrings,
-                    false,  // bKeepLeadingAndClosingQuotes
-                    false,  // bMergeDelimiter
-                    true    // bSkipBOM
-                );
-                const int nTokens2 = CSLCount(papszTokens);
-                CSLDestroy(papszTokens);
-                if (nTokens1 >= 2 && nTokens1 == nTokens2)
+                chDelimiter = '\t';
+            }
+            else
+            {
+                for (int nDontHonourStrings = 0; nDontHonourStrings <= 1;
+                     nDontHonourStrings++)
                 {
-                    chDelimiter = '\t';
-                    break;
+                    const bool bHonourStrings =
+                        !CPL_TO_BOOL(nDontHonourStrings);
+                    // Read the first 2 lines to see if they have the same number
+                    // of fields, if using tabulation.
+                    VSIRewindL(fp);
+                    char **papszTokens = CSVReadParseLine3L(
+                        fp, nMaxLineSizeAsSize_t, "\t", bHonourStrings,
+                        false,  // bKeepLeadingAndClosingQuotes
+                        false,  // bMergeDelimiter
+                        true    // bSkipBOM
+                    );
+                    const int nTokens1 = CSLCount(papszTokens);
+                    CSLDestroy(papszTokens);
+                    papszTokens = CSVReadParseLine3L(
+                        fp, nMaxLineSizeAsSize_t, "\t", bHonourStrings,
+                        false,  // bKeepLeadingAndClosingQuotes
+                        false,  // bMergeDelimiter
+                        true    // bSkipBOM
+                    );
+                    const int nTokens2 = CSLCount(papszTokens);
+                    CSLDestroy(papszTokens);
+                    if (nTokens1 >= 2 && nTokens1 == nTokens2)
+                    {
+                        chDelimiter = '\t';
+                        break;
+                    }
                 }
             }
         }
+
+        // GNIS specific.
+        if (pszGeonamesGeomFieldPrefix != nullptr &&
+            osLine.find('|') != std::string::npos)
+            chDelimiter = '|';
     }
-
-    VSIRewindL(fp);
-
-#if 0
-    const char *pszDelimiter = CSLFetchNameValueDef(papszOpenOptionsIn,
-                                                    "SEPARATOR", "AUTO");
-    if( !EQUAL(pszDelimiter, "AUTO") )
-    {
-        if (EQUAL(pszDelimiter, "COMMA"))
-            chDelimiter = ',';
-        else if (EQUAL(pszDelimiter, "SEMICOLON"))
-            chDelimiter = ';';
-        else if (EQUAL(pszDelimiter, "TAB"))
-            chDelimiter = '\t';
-        else if (EQUAL(pszDelimiter, "SPACE"))
-            chDelimiter = ' ';
-        else
-        {
-            CPLError(CE_Warning, CPLE_AppDefined,
-                     "SEPARATOR=%s not understood, use one of COMMA, "
-                     "SEMICOLON, SPACE or TAB.",
-                     pszDelimiter);
-        }
-    }
-#endif
-
-    // GNIS specific.
-    if (pszGeonamesGeomFieldPrefix != nullptr &&
-        osLine.find('|') != std::string::npos)
+    else if (EQUAL(pszDelimiter, "COMMA"))
+        chDelimiter = ',';
+    else if (EQUAL(pszDelimiter, "SEMICOLON"))
+        chDelimiter = ';';
+    else if (EQUAL(pszDelimiter, "TAB"))
+        chDelimiter = '\t';
+    else if (EQUAL(pszDelimiter, "SPACE"))
+        chDelimiter = ' ';
+    else if (EQUAL(pszDelimiter, "PIPE"))
         chDelimiter = '|';
-
-    char szDelimiter[2];
-    szDelimiter[0] = chDelimiter;
-    szDelimiter[1] = 0;
-    char **papszFields =
-        CSVReadParseLine3L(fp, nMaxLineSizeAsSize_t, szDelimiter,
-                           true,   // bHonourStrings,
-                           false,  // bKeepLeadingAndClosingQuotes
-                           false,  // bMergeDelimiter
-                           true    // bSkipBOM
-        );
-
-    if (CSLCount(papszFields) < 2)
+    else
     {
-        VSIFCloseL(fp);
-        CSLDestroy(papszFields);
-        return false;
+        CPLError(CE_Warning, CPLE_AppDefined,
+                 "SEPARATOR=%s not understood, use one of COMMA, "
+                 "SEMICOLON, TAB, SPACE or PIPE",
+                 pszDelimiter);
     }
 
     VSIRewindL(fp);
-    CSLDestroy(papszFields);
 
     // Create a layer.
-    nLayers++;
-    papoLayers = static_cast<OGRLayer **>(
-        CPLRealloc(papoLayers, sizeof(void *) * nLayers));
-
     if (pszNfdcRunwaysGeomField != nullptr)
     {
         osLayerName += "_";
@@ -896,18 +896,21 @@ bool OGRCSVDataSource::OpenTable(const char *pszFilename,
     if (EQUAL(pszFilename, "/vsistdin/"))
         osLayerName = "layer";
 
-    OGRCSVLayer *poCSVLayer =
-        new OGRCSVLayer(osLayerName, fp, nMaxLineSize, pszFilename, FALSE,
-                        bUpdate, chDelimiter);
+    auto poCSVLayer =
+        std::make_unique<OGRCSVLayer>(this, osLayerName, fp, nMaxLineSize,
+                                      pszFilename, FALSE, bUpdate, chDelimiter);
     poCSVLayer->BuildFeatureDefn(pszNfdcRunwaysGeomField,
                                  pszGeonamesGeomFieldPrefix,
                                  papszOpenOptionsIn);
-    OGRLayer *poLayer = poCSVLayer;
     if (bUpdate)
     {
-        poLayer = new OGRCSVEditableLayer(poCSVLayer, papszOpenOptionsIn);
+        m_apoLayers.emplace_back(std::make_unique<OGRCSVEditableLayer>(
+            poCSVLayer.release(), papszOpenOptionsIn));
+    }
+    else
+    {
+        m_apoLayers.emplace_back(std::move(poCSVLayer));
     }
-    papoLayers[nLayers - 1] = poLayer;
 
     return true;
 }
@@ -916,10 +919,10 @@ bool OGRCSVDataSource::OpenTable(const char *pszFilename,
 /*                           ICreateLayer()                             */
 /************************************************************************/
 
-OGRLayer *OGRCSVDataSource::ICreateLayer(const char *pszLayerName,
-                                         OGRSpatialReference *poSpatialRef,
-                                         OGRwkbGeometryType eGType,
-                                         char **papszOptions)
+OGRLayer *
+OGRCSVDataSource::ICreateLayer(const char *pszLayerName,
+                               const OGRGeomFieldDefn *poSrcGeomFieldDefn,
+                               CSLConstList papszOptions)
 {
     // Verify we are in update mode.
     if (!bUpdate)
@@ -932,6 +935,11 @@ OGRLayer *OGRCSVDataSource::ICreateLayer(const char *pszLayerName,
         return nullptr;
     }
 
+    const auto eGType =
+        poSrcGeomFieldDefn ? poSrcGeomFieldDefn->GetType() : wkbNone;
+    const auto poSpatialRef =
+        poSrcGeomFieldDefn ? poSrcGeomFieldDefn->GetSpatialRef() : nullptr;
+
     // Verify that the datasource is a directory.
     VSIStatBufL sStatBuf;
 
@@ -949,10 +957,23 @@ OGRLayer *OGRCSVDataSource::ICreateLayer(const char *pszLayerName,
         return nullptr;
     }
 
+    const bool bCreateCSVT =
+        CPLTestBool(CSLFetchNameValueDef(papszOptions, "CREATE_CSVT", "NO"));
+
     // What filename would we use?
     CPLString osFilename;
 
-    if (osDefaultCSVName != "")
+    if (strcmp(pszName, "/vsistdout/") == 0)
+    {
+        osFilename = pszName;
+        if (bCreateCSVT)
+        {
+            CPLError(CE_Failure, CPLE_AppDefined,
+                     "CREATE_CSVT is not compatible with /vsistdout/ output");
+            return nullptr;
+        }
+    }
+    else if (osDefaultCSVName != "")
     {
         osFilename = CPLFormFilename(pszName, osDefaultCSVName, nullptr);
         osDefaultCSVName = "";
@@ -996,8 +1017,8 @@ OGRLayer *OGRCSVDataSource::ICreateLayer(const char *pszLayerName,
 
     // Create a layer.
 
-    OGRCSVLayer *poCSVLayer = new OGRCSVLayer(
-        pszLayerName, nullptr, -1, osFilename, true, true, chDelimiter);
+    auto poCSVLayer = std::make_unique<OGRCSVLayer>(
+        this, pszLayerName, nullptr, -1, osFilename, true, true, chDelimiter);
 
     poCSVLayer->BuildFeatureDefn();
 
@@ -1007,7 +1028,7 @@ OGRLayer *OGRCSVDataSource::ICreateLayer(const char *pszLayerName,
 
     if (pszCRLFFormat == nullptr)
     {
-#ifdef WIN32
+#ifdef _WIN32
         bUseCRLF = true;
 #endif
     }
@@ -1020,7 +1041,7 @@ OGRLayer *OGRCSVDataSource::ICreateLayer(const char *pszLayerName,
         CPLError(CE_Warning, CPLE_AppDefined,
                  "LINEFORMAT=%s not understood, use one of CRLF or LF.",
                  pszCRLFFormat);
-#ifdef WIN32
+#ifdef _WIN32
         bUseCRLF = true;
 #endif
     }
@@ -1079,13 +1100,12 @@ OGRLayer *OGRCSVDataSource::ICreateLayer(const char *pszLayerName,
     }
 
     // Should we create a CSVT file?
-    const char *pszCreateCSVT = CSLFetchNameValue(papszOptions, "CREATE_CSVT");
-    if (pszCreateCSVT && CPLTestBool(pszCreateCSVT))
+    if (bCreateCSVT)
     {
         poCSVLayer->SetCreateCSVT(true);
 
         // Create .prj file.
-        if (poSpatialRef != nullptr && osFilename != "/vsistdout/")
+        if (poSpatialRef != nullptr)
         {
             char *pszWKT = nullptr;
             poSpatialRef->exportToWkt(&pszWKT);
@@ -1108,14 +1128,21 @@ OGRLayer *OGRCSVDataSource::ICreateLayer(const char *pszLayerName,
     if (pszWriteBOM)
         poCSVLayer->SetWriteBOM(CPLTestBool(pszWriteBOM));
 
-    nLayers++;
-    papoLayers = static_cast<OGRLayer **>(
-        CPLRealloc(papoLayers, sizeof(void *) * nLayers));
-    OGRLayer *poLayer = poCSVLayer;
+    if (poCSVLayer->GetLayerDefn()->GetGeomFieldCount() > 0 &&
+        poSrcGeomFieldDefn)
+    {
+        auto poGeomFieldDefn = poCSVLayer->GetLayerDefn()->GetGeomFieldDefn(0);
+        poGeomFieldDefn->SetCoordinatePrecision(
+            poSrcGeomFieldDefn->GetCoordinatePrecision());
+    }
+
     if (osFilename != "/vsistdout/")
-        poLayer = new OGRCSVEditableLayer(poCSVLayer, nullptr);
-    papoLayers[nLayers - 1] = poLayer;
-    return poLayer;
+        m_apoLayers.emplace_back(std::make_unique<OGRCSVEditableLayer>(
+            poCSVLayer.release(), nullptr));
+    else
+        m_apoLayers.emplace_back(std::move(poCSVLayer));
+
+    return m_apoLayers.back()->GetLayer();
 }
 
 /************************************************************************/
@@ -1136,33 +1163,20 @@ OGRErr OGRCSVDataSource::DeleteLayer(int iLayer)
         return OGRERR_FAILURE;
     }
 
-    if (iLayer < 0 || iLayer >= nLayers)
+    if (iLayer < 0 || iLayer >= GetLayerCount())
     {
         CPLError(CE_Failure, CPLE_AppDefined,
                  "Layer %d not in legal range of 0 to %d.", iLayer,
-                 nLayers - 1);
+                 GetLayerCount() - 1);
         return OGRERR_FAILURE;
     }
 
-    char *pszFilename = CPLStrdup(CPLFormFilename(
-        pszName, papoLayers[iLayer]->GetLayerDefn()->GetName(), "csv"));
-    char *pszFilenameCSVT = CPLStrdup(CPLFormFilename(
-        pszName, papoLayers[iLayer]->GetLayerDefn()->GetName(), "csvt"));
-
-    delete papoLayers[iLayer];
-
-    while (iLayer < nLayers - 1)
+    for (const auto &osFilename : m_apoLayers[iLayer]->GetFileList())
     {
-        papoLayers[iLayer] = papoLayers[iLayer + 1];
-        iLayer++;
+        VSIUnlink(osFilename.c_str());
     }
 
-    nLayers--;
-
-    VSIUnlink(pszFilename);
-    CPLFree(pszFilename);
-    VSIUnlink(pszFilenameCSVT);
-    CPLFree(pszFilenameCSVT);
+    m_apoLayers.erase(m_apoLayers.begin() + iLayer);
 
     return OGRERR_NONE;
 }
@@ -1178,3 +1192,20 @@ void OGRCSVDataSource::CreateForSingleFile(const char *pszDirname,
     bUpdate = true;
     osDefaultCSVName = CPLGetFilename(pszFilename);
 }
+
+/************************************************************************/
+/*                            GetFileList()                             */
+/************************************************************************/
+
+char **OGRCSVDataSource::GetFileList()
+{
+    CPLStringList oFileList;
+    for (auto &poLayer : m_apoLayers)
+    {
+        for (const auto &osFilename : poLayer->GetFileList())
+        {
+            oFileList.AddString(osFilename.c_str());
+        }
+    }
+    return oFileList.StealList();
+}
