@@ -51,109 +51,6 @@
 #include "filegdb_fielddomain.h"
 #include "filegdb_relationship.h"
 
-#include <random>
-#include <sstream>
-
-/************************************************************************/
-/*                        CPLGettimeofday()                             */
-/************************************************************************/
-
-#if defined(_WIN32) && !defined(__CYGWIN__)
-#include <sys/timeb.h>
-
-namespace
-{
-struct CPLTimeVal
-{
-    time_t tv_sec; /* seconds */
-    long tv_usec;  /* and microseconds */
-};
-}  // namespace
-
-static int CPLGettimeofday(struct CPLTimeVal *tp, void * /* timezonep*/)
-{
-    struct _timeb theTime;
-
-    _ftime(&theTime);
-    tp->tv_sec = static_cast<time_t>(theTime.time);
-    tp->tv_usec = theTime.millitm * 1000;
-    return 0;
-}
-#else
-#include <sys/time.h> /* for gettimeofday() */
-#define CPLTimeVal timeval
-#define CPLGettimeofday(t, u) gettimeofday(t, u)
-#endif
-
-/***********************************************************************/
-/*                      OFGDBGenerateUUID()                            */
-/***********************************************************************/
-
-// Probably not the best UUID generator ever. One issue is that mt19937
-// uses only a 32-bit seed.
-std::string OFGDBGenerateUUID()
-{
-    struct CPLTimeVal tv;
-    memset(&tv, 0, sizeof(tv));
-    static uint32_t nCounter = 0;
-    const bool bReproducibleUUID =
-        CPLTestBool(CPLGetConfigOption("OPENFILEGDB_REPRODUCIBLE_UUID", "NO"));
-
-    std::stringstream ss;
-
-    {
-        if (!bReproducibleUUID)
-            CPLGettimeofday(&tv, nullptr);
-        std::mt19937 gen(++nCounter +
-                         (bReproducibleUUID
-                              ? 0
-                              : static_cast<unsigned>(tv.tv_sec ^ tv.tv_usec)));
-        std::uniform_int_distribution<> dis(0, 15);
-
-        ss << "{";
-        ss << std::hex;
-        for (int i = 0; i < 8; i++)
-        {
-            ss << dis(gen);
-        }
-        ss << "-";
-        for (int i = 0; i < 4; i++)
-        {
-            ss << dis(gen);
-        }
-        ss << "-4";
-        for (int i = 0; i < 3; i++)
-        {
-            ss << dis(gen);
-        }
-    }
-
-    {
-        if (!bReproducibleUUID)
-            CPLGettimeofday(&tv, nullptr);
-        std::mt19937 gen(++nCounter +
-                         (bReproducibleUUID
-                              ? 0
-                              : static_cast<unsigned>(tv.tv_sec ^ tv.tv_usec)));
-        std::uniform_int_distribution<> dis(0, 15);
-        std::uniform_int_distribution<> dis2(8, 11);
-
-        ss << "-";
-        ss << dis2(gen);
-        for (int i = 0; i < 3; i++)
-        {
-            ss << dis(gen);
-        }
-        ss << "-";
-        for (int i = 0; i < 12; i++)
-        {
-            ss << dis(gen);
-        };
-        ss << "}";
-        return ss.str();
-    }
-}
-
 /***********************************************************************/
 /*                    GetExistingSpatialRef()                          */
 /***********************************************************************/
@@ -664,17 +561,17 @@ bool OGROpenFileGDBDataSource::CreateGDBSystemCatalog()
 {
     // Write GDB_SystemCatalog file
     m_osGDBSystemCatalogFilename =
-        CPLFormFilename(m_pszName, "a00000001.gdbtable", nullptr);
+        CPLFormFilename(m_osDirName.c_str(), "a00000001.gdbtable", nullptr);
     FileGDBTable oTable;
     if (!oTable.Create(m_osGDBSystemCatalogFilename.c_str(), 4, FGTGT_NONE,
                        false, false) ||
-        !oTable.CreateField(cpl::make_unique<FileGDBField>(
+        !oTable.CreateField(std::make_unique<FileGDBField>(
             "ID", std::string(), FGFT_OBJECTID, false, 0,
             FileGDBField::UNSET_FIELD)) ||
-        !oTable.CreateField(cpl::make_unique<FileGDBField>(
+        !oTable.CreateField(std::make_unique<FileGDBField>(
             "Name", std::string(), FGFT_STRING, false, 160,
             FileGDBField::UNSET_FIELD)) ||
-        !oTable.CreateField(cpl::make_unique<FileGDBField>(
+        !oTable.CreateField(std::make_unique<FileGDBField>(
             "FileFormat", std::string(), FGFT_INT32, false, 0,
             FileGDBField::UNSET_FIELD)))
     {
@@ -700,7 +597,7 @@ bool OGROpenFileGDBDataSource::CreateGDBSystemCatalog()
             return false;
     }
 
-    m_apoHiddenLayers.emplace_back(cpl::make_unique<OGROpenFileGDBLayer>(
+    m_apoHiddenLayers.emplace_back(std::make_unique<OGROpenFileGDBLayer>(
         this, m_osGDBSystemCatalogFilename.c_str(), "GDB_SystemCatalog", "", "",
         true));
 
@@ -715,16 +612,16 @@ bool OGROpenFileGDBDataSource::CreateGDBDBTune()
 {
     // Write GDB_DBTune file
     const std::string osFilename(
-        CPLFormFilename(m_pszName, "a00000002.gdbtable", nullptr));
+        CPLFormFilename(m_osDirName.c_str(), "a00000002.gdbtable", nullptr));
     FileGDBTable oTable;
     if (!oTable.Create(osFilename.c_str(), 4, FGTGT_NONE, false, false) ||
-        !oTable.CreateField(cpl::make_unique<FileGDBField>(
+        !oTable.CreateField(std::make_unique<FileGDBField>(
             "Keyword", std::string(), FGFT_STRING, false, 32,
             FileGDBField::UNSET_FIELD)) ||
-        !oTable.CreateField(cpl::make_unique<FileGDBField>(
+        !oTable.CreateField(std::make_unique<FileGDBField>(
             "ParameterName", std::string(), FGFT_STRING, false, 32,
             FileGDBField::UNSET_FIELD)) ||
-        !oTable.CreateField(cpl::make_unique<FileGDBField>(
+        !oTable.CreateField(std::make_unique<FileGDBField>(
             "ConfigString", std::string(), FGFT_STRING, true, 2048,
             FileGDBField::UNSET_FIELD)))
     {
@@ -793,7 +690,7 @@ bool OGROpenFileGDBDataSource::CreateGDBDBTune()
             return false;
     }
 
-    m_apoHiddenLayers.emplace_back(cpl::make_unique<OGROpenFileGDBLayer>(
+    m_apoHiddenLayers.emplace_back(std::make_unique<OGROpenFileGDBLayer>(
         this, osFilename.c_str(), "GDB_DBTune", "", "", true));
 
     return oTable.Sync();
@@ -807,51 +704,51 @@ bool OGROpenFileGDBDataSource::CreateGDBSpatialRefs()
 {
     // Write GDB_SpatialRefs file
     m_osGDBSpatialRefsFilename =
-        CPLFormFilename(m_pszName, "a00000003.gdbtable", nullptr);
+        CPLFormFilename(m_osDirName.c_str(), "a00000003.gdbtable", nullptr);
     FileGDBTable oTable;
     if (!oTable.Create(m_osGDBSpatialRefsFilename.c_str(), 4, FGTGT_NONE, false,
                        false) ||
-        !oTable.CreateField(cpl::make_unique<FileGDBField>(
+        !oTable.CreateField(std::make_unique<FileGDBField>(
             "ID", std::string(), FGFT_OBJECTID, false, 0,
             FileGDBField::UNSET_FIELD)) ||
-        !oTable.CreateField(cpl::make_unique<FileGDBField>(
+        !oTable.CreateField(std::make_unique<FileGDBField>(
             "SRTEXT", std::string(), FGFT_STRING, false, 2048,
             FileGDBField::UNSET_FIELD)) ||
-        !oTable.CreateField(cpl::make_unique<FileGDBField>(
+        !oTable.CreateField(std::make_unique<FileGDBField>(
             "FalseX", std::string(), FGFT_FLOAT64, true, 0,
             FileGDBField::UNSET_FIELD)) ||
-        !oTable.CreateField(cpl::make_unique<FileGDBField>(
+        !oTable.CreateField(std::make_unique<FileGDBField>(
             "FalseY", std::string(), FGFT_FLOAT64, true, 0,
             FileGDBField::UNSET_FIELD)) ||
-        !oTable.CreateField(cpl::make_unique<FileGDBField>(
+        !oTable.CreateField(std::make_unique<FileGDBField>(
             "XYUnits", std::string(), FGFT_FLOAT64, true, 0,
             FileGDBField::UNSET_FIELD)) ||
-        !oTable.CreateField(cpl::make_unique<FileGDBField>(
+        !oTable.CreateField(std::make_unique<FileGDBField>(
             "FalseZ", std::string(), FGFT_FLOAT64, true, 0,
             FileGDBField::UNSET_FIELD)) ||
-        !oTable.CreateField(cpl::make_unique<FileGDBField>(
+        !oTable.CreateField(std::make_unique<FileGDBField>(
             "ZUnits", std::string(), FGFT_FLOAT64, true, 0,
             FileGDBField::UNSET_FIELD)) ||
-        !oTable.CreateField(cpl::make_unique<FileGDBField>(
+        !oTable.CreateField(std::make_unique<FileGDBField>(
             "FalseM", std::string(), FGFT_FLOAT64, true, 0,
             FileGDBField::UNSET_FIELD)) ||
-        !oTable.CreateField(cpl::make_unique<FileGDBField>(
+        !oTable.CreateField(std::make_unique<FileGDBField>(
             "MUnits", std::string(), FGFT_FLOAT64, true, 0,
             FileGDBField::UNSET_FIELD)) ||
-        !oTable.CreateField(cpl::make_unique<FileGDBField>(
+        !oTable.CreateField(std::make_unique<FileGDBField>(
             "XYTolerance", std::string(), FGFT_FLOAT64, true, 0,
             FileGDBField::UNSET_FIELD)) ||
-        !oTable.CreateField(cpl::make_unique<FileGDBField>(
+        !oTable.CreateField(std::make_unique<FileGDBField>(
             "ZTolerance", std::string(), FGFT_FLOAT64, true, 0,
             FileGDBField::UNSET_FIELD)) ||
-        !oTable.CreateField(cpl::make_unique<FileGDBField>(
+        !oTable.CreateField(std::make_unique<FileGDBField>(
             "MTolerance", std::string(), FGFT_FLOAT64, true, 0,
             FileGDBField::UNSET_FIELD)))
     {
         return false;
     }
 
-    m_apoHiddenLayers.emplace_back(cpl::make_unique<OGROpenFileGDBLayer>(
+    m_apoHiddenLayers.emplace_back(std::make_unique<OGROpenFileGDBLayer>(
         this, m_osGDBSpatialRefsFilename.c_str(), "GDB_SpatialRefs", "", "",
         true));
 
@@ -887,56 +784,56 @@ bool OGROpenFileGDBDataSource::CreateGDBItems()
     }
 
     m_osGDBItemsFilename =
-        CPLFormFilename(m_pszName, "a00000004.gdbtable", nullptr);
+        CPLFormFilename(m_osDirName.c_str(), "a00000004.gdbtable", nullptr);
     FileGDBTable oTable;
     if (!oTable.Create(m_osGDBItemsFilename.c_str(), 4, FGTGT_POLYGON, false,
                        false) ||
-        !oTable.CreateField(cpl::make_unique<FileGDBField>(
+        !oTable.CreateField(std::make_unique<FileGDBField>(
             "ObjectID", std::string(), FGFT_OBJECTID, false, 0,
             FileGDBField::UNSET_FIELD)) ||
-        !oTable.CreateField(cpl::make_unique<FileGDBField>(
+        !oTable.CreateField(std::make_unique<FileGDBField>(
             "UUID", std::string(), FGFT_GLOBALID, false, 0,
             FileGDBField::UNSET_FIELD)) ||
-        !oTable.CreateField(cpl::make_unique<FileGDBField>(
+        !oTable.CreateField(std::make_unique<FileGDBField>(
             "Type", std::string(), FGFT_GUID, false, 0,
             FileGDBField::UNSET_FIELD)) ||
-        !oTable.CreateField(cpl::make_unique<FileGDBField>(
+        !oTable.CreateField(std::make_unique<FileGDBField>(
             "Name", std::string(), FGFT_STRING, true, 160,
             FileGDBField::UNSET_FIELD)) ||
-        !oTable.CreateField(cpl::make_unique<FileGDBField>(
+        !oTable.CreateField(std::make_unique<FileGDBField>(
             "PhysicalName", std::string(), FGFT_STRING, true, 160,
             FileGDBField::UNSET_FIELD)) ||
-        !oTable.CreateField(cpl::make_unique<FileGDBField>(
+        !oTable.CreateField(std::make_unique<FileGDBField>(
             "Path", std::string(), FGFT_STRING, true, 260,
             FileGDBField::UNSET_FIELD)) ||
-        !oTable.CreateField(cpl::make_unique<FileGDBField>(
+        !oTable.CreateField(std::make_unique<FileGDBField>(
             "DatasetSubtype1", std::string(), FGFT_INT32, true, 0,
             FileGDBField::UNSET_FIELD)) ||
-        !oTable.CreateField(cpl::make_unique<FileGDBField>(
+        !oTable.CreateField(std::make_unique<FileGDBField>(
             "DatasetSubtype2", std::string(), FGFT_INT32, true, 0,
             FileGDBField::UNSET_FIELD)) ||
-        !oTable.CreateField(cpl::make_unique<FileGDBField>(
+        !oTable.CreateField(std::make_unique<FileGDBField>(
             "DatasetInfo1", std::string(), FGFT_STRING, true, 255,
             FileGDBField::UNSET_FIELD)) ||
-        !oTable.CreateField(cpl::make_unique<FileGDBField>(
+        !oTable.CreateField(std::make_unique<FileGDBField>(
             "DatasetInfo2", std::string(), FGFT_STRING, true, 255,
             FileGDBField::UNSET_FIELD)) ||
-        !oTable.CreateField(cpl::make_unique<FileGDBField>(
+        !oTable.CreateField(std::make_unique<FileGDBField>(
             "URL", std::string(), FGFT_STRING, true, 255,
             FileGDBField::UNSET_FIELD)) ||
-        !oTable.CreateField(cpl::make_unique<FileGDBField>(
+        !oTable.CreateField(std::make_unique<FileGDBField>(
             "Definition", std::string(), FGFT_XML, true, 0,
             FileGDBField::UNSET_FIELD)) ||
-        !oTable.CreateField(cpl::make_unique<FileGDBField>(
+        !oTable.CreateField(std::make_unique<FileGDBField>(
             "Documentation", std::string(), FGFT_XML, true, 0,
             FileGDBField::UNSET_FIELD)) ||
-        !oTable.CreateField(cpl::make_unique<FileGDBField>(
+        !oTable.CreateField(std::make_unique<FileGDBField>(
             "ItemInfo", std::string(), FGFT_XML, true, 0,
             FileGDBField::UNSET_FIELD)) ||
-        !oTable.CreateField(cpl::make_unique<FileGDBField>(
+        !oTable.CreateField(std::make_unique<FileGDBField>(
             "Properties", std::string(), FGFT_INT32, true, 0,
             FileGDBField::UNSET_FIELD)) ||
-        !oTable.CreateField(cpl::make_unique<FileGDBField>(
+        !oTable.CreateField(std::make_unique<FileGDBField>(
             "Defaults", std::string(), FGFT_BINARY, true, 0,
             FileGDBField::UNSET_FIELD)) ||
         !oTable.CreateField(std::move(poGeomField)))
@@ -984,7 +881,7 @@ bool OGROpenFileGDBDataSource::CreateGDBItems()
         "</DEWorkspace>");
     fields[14].Integer = 0;
 
-    m_apoHiddenLayers.emplace_back(cpl::make_unique<OGROpenFileGDBLayer>(
+    m_apoHiddenLayers.emplace_back(std::make_unique<OGROpenFileGDBLayer>(
         this, m_osGDBItemsFilename.c_str(), "GDB_Items", "", "", true));
 
     return oTable.CreateFeature(fields, nullptr) && oTable.Sync();
@@ -998,19 +895,19 @@ bool OGROpenFileGDBDataSource::CreateGDBItemTypes()
 {
     // Write GDB_ItemTypes file
     const std::string osFilename(
-        CPLFormFilename(m_pszName, "a00000005.gdbtable", nullptr));
+        CPLFormFilename(m_osDirName.c_str(), "a00000005.gdbtable", nullptr));
     FileGDBTable oTable;
     if (!oTable.Create(osFilename.c_str(), 4, FGTGT_NONE, false, false) ||
-        !oTable.CreateField(cpl::make_unique<FileGDBField>(
+        !oTable.CreateField(std::make_unique<FileGDBField>(
             "ObjectID", std::string(), FGFT_OBJECTID, false, 0,
             FileGDBField::UNSET_FIELD)) ||
-        !oTable.CreateField(cpl::make_unique<FileGDBField>(
+        !oTable.CreateField(std::make_unique<FileGDBField>(
             "UUID", std::string(), FGFT_GUID, false, 0,
             FileGDBField::UNSET_FIELD)) ||
-        !oTable.CreateField(cpl::make_unique<FileGDBField>(
+        !oTable.CreateField(std::make_unique<FileGDBField>(
             "ParentTypeID", std::string(), FGFT_GUID, false, 0,
             FileGDBField::UNSET_FIELD)) ||
-        !oTable.CreateField(cpl::make_unique<FileGDBField>(
+        !oTable.CreateField(std::make_unique<FileGDBField>(
             "Name", std::string(), FGFT_STRING, false, 160,
             FileGDBField::UNSET_FIELD)))
     {
@@ -1098,7 +995,7 @@ bool OGROpenFileGDBDataSource::CreateGDBItemTypes()
             return false;
     }
 
-    m_apoHiddenLayers.emplace_back(cpl::make_unique<OGROpenFileGDBLayer>(
+    m_apoHiddenLayers.emplace_back(std::make_unique<OGROpenFileGDBLayer>(
         this, osFilename.c_str(), "GDB_ItemTypes", "", "", true));
 
     return oTable.Sync();
@@ -1112,36 +1009,36 @@ bool OGROpenFileGDBDataSource::CreateGDBItemRelationships()
 {
     // Write GDB_ItemRelationships file
     m_osGDBItemRelationshipsFilename =
-        CPLFormFilename(m_pszName, "a00000006.gdbtable", nullptr);
+        CPLFormFilename(m_osDirName.c_str(), "a00000006.gdbtable", nullptr);
     FileGDBTable oTable;
     if (!oTable.Create(m_osGDBItemRelationshipsFilename.c_str(), 4, FGTGT_NONE,
                        false, false) ||
-        !oTable.CreateField(cpl::make_unique<FileGDBField>(
+        !oTable.CreateField(std::make_unique<FileGDBField>(
             "ObjectID", std::string(), FGFT_OBJECTID, false, 0,
             FileGDBField::UNSET_FIELD)) ||
-        !oTable.CreateField(cpl::make_unique<FileGDBField>(
+        !oTable.CreateField(std::make_unique<FileGDBField>(
             "UUID", std::string(), FGFT_GLOBALID, false, 0,
             FileGDBField::UNSET_FIELD)) ||
-        !oTable.CreateField(cpl::make_unique<FileGDBField>(
+        !oTable.CreateField(std::make_unique<FileGDBField>(
             "OriginID", std::string(), FGFT_GUID, false, 0,
             FileGDBField::UNSET_FIELD)) ||
-        !oTable.CreateField(cpl::make_unique<FileGDBField>(
+        !oTable.CreateField(std::make_unique<FileGDBField>(
             "DestID", std::string(), FGFT_GUID, false, 0,
             FileGDBField::UNSET_FIELD)) ||
-        !oTable.CreateField(cpl::make_unique<FileGDBField>(
+        !oTable.CreateField(std::make_unique<FileGDBField>(
             "Type", std::string(), FGFT_GUID, false, 0,
             FileGDBField::UNSET_FIELD)) ||
-        !oTable.CreateField(cpl::make_unique<FileGDBField>(
+        !oTable.CreateField(std::make_unique<FileGDBField>(
             "Attributes", std::string(), FGFT_XML, true, 0,
             FileGDBField::UNSET_FIELD)) ||
-        !oTable.CreateField(cpl::make_unique<FileGDBField>(
+        !oTable.CreateField(std::make_unique<FileGDBField>(
             "Properties", std::string(), FGFT_INT32, true, 0,
             FileGDBField::UNSET_FIELD)))
     {
         return false;
     }
 
-    m_apoHiddenLayers.emplace_back(cpl::make_unique<OGROpenFileGDBLayer>(
+    m_apoHiddenLayers.emplace_back(std::make_unique<OGROpenFileGDBLayer>(
         this, m_osGDBItemRelationshipsFilename.c_str(), "GDB_ItemRelationships",
         "", "", true));
 
@@ -1156,31 +1053,31 @@ bool OGROpenFileGDBDataSource::CreateGDBItemRelationshipTypes()
 {
     // Write GDB_ItemRelationshipTypes file
     const std::string osFilename(
-        CPLFormFilename(m_pszName, "a00000007.gdbtable", nullptr));
+        CPLFormFilename(m_osDirName.c_str(), "a00000007.gdbtable", nullptr));
     FileGDBTable oTable;
     if (!oTable.Create(osFilename.c_str(), 4, FGTGT_NONE, false, false) ||
-        !oTable.CreateField(cpl::make_unique<FileGDBField>(
+        !oTable.CreateField(std::make_unique<FileGDBField>(
             "ObjectID", std::string(), FGFT_OBJECTID, false, 0,
             FileGDBField::UNSET_FIELD)) ||
-        !oTable.CreateField(cpl::make_unique<FileGDBField>(
+        !oTable.CreateField(std::make_unique<FileGDBField>(
             "UUID", std::string(), FGFT_GUID, false, 0,
             FileGDBField::UNSET_FIELD)) ||
-        !oTable.CreateField(cpl::make_unique<FileGDBField>(
+        !oTable.CreateField(std::make_unique<FileGDBField>(
             "OrigItemTypeID", std::string(), FGFT_GUID, false, 0,
             FileGDBField::UNSET_FIELD)) ||
-        !oTable.CreateField(cpl::make_unique<FileGDBField>(
+        !oTable.CreateField(std::make_unique<FileGDBField>(
             "DestItemTypeID", std::string(), FGFT_GUID, false, 0,
             FileGDBField::UNSET_FIELD)) ||
-        !oTable.CreateField(cpl::make_unique<FileGDBField>(
+        !oTable.CreateField(std::make_unique<FileGDBField>(
             "Name", std::string(), FGFT_STRING, true, 160,
             FileGDBField::UNSET_FIELD)) ||
-        !oTable.CreateField(cpl::make_unique<FileGDBField>(
+        !oTable.CreateField(std::make_unique<FileGDBField>(
             "ForwardLabel", std::string(), FGFT_STRING, true, 255,
             FileGDBField::UNSET_FIELD)) ||
-        !oTable.CreateField(cpl::make_unique<FileGDBField>(
+        !oTable.CreateField(std::make_unique<FileGDBField>(
             "BackwardLabel", std::string(), FGFT_STRING, true, 255,
             FileGDBField::UNSET_FIELD)) ||
-        !oTable.CreateField(cpl::make_unique<FileGDBField>(
+        !oTable.CreateField(std::make_unique<FileGDBField>(
             "IsContainment", std::string(), FGFT_INT16, true, 0,
             FileGDBField::UNSET_FIELD)))
     {
@@ -1273,7 +1170,7 @@ bool OGROpenFileGDBDataSource::CreateGDBItemRelationshipTypes()
             return false;
     }
 
-    m_apoHiddenLayers.emplace_back(cpl::make_unique<OGROpenFileGDBLayer>(
+    m_apoHiddenLayers.emplace_back(std::make_unique<OGROpenFileGDBLayer>(
         this, osFilename.c_str(), "GDB_ItemRelationshipTypes", "", "", true));
 
     return oTable.Sync();
@@ -1308,8 +1205,7 @@ bool OGROpenFileGDBDataSource::Create(const char *pszName)
         return false;
     }
 
-    m_pszName = CPLStrdup(pszName);
-    m_osDirName = m_pszName;
+    m_osDirName = pszName;
     eAccess = GA_Update;
 
     {
@@ -1346,10 +1242,10 @@ bool OGROpenFileGDBDataSource::Create(const char *pszName)
 /*                             ICreateLayer()                           */
 /************************************************************************/
 
-OGRLayer *OGROpenFileGDBDataSource::ICreateLayer(const char *pszLayerName,
-                                                 OGRSpatialReference *poSRS,
-                                                 OGRwkbGeometryType eType,
-                                                 char **papszOptions)
+OGRLayer *
+OGROpenFileGDBDataSource::ICreateLayer(const char *pszLayerName,
+                                       const OGRGeomFieldDefn *poGeomFieldDefn,
+                                       CSLConstList papszOptions)
 {
     if (eAccess != GA_Update)
         return nullptr;
@@ -1363,6 +1259,8 @@ OGRLayer *OGROpenFileGDBDataSource::ICreateLayer(const char *pszLayerName,
         return nullptr;
     }
 
+    auto eType = poGeomFieldDefn ? poGeomFieldDefn->GetType() : wkbNone;
+
     FileGDBTable oTable;
     if (!oTable.Open(m_osGDBSystemCatalogFilename.c_str(), false))
         return nullptr;
@@ -1370,7 +1268,7 @@ OGRLayer *OGROpenFileGDBDataSource::ICreateLayer(const char *pszLayerName,
     oTable.Close();
 
     const std::string osFilename(CPLFormFilename(
-        m_pszName, CPLSPrintf("a%08x.gdbtable", nTableNum), nullptr));
+        m_osDirName.c_str(), CPLSPrintf("a%08x.gdbtable", nTableNum), nullptr));
 
     if (wkbFlatten(eType) == wkbLineString)
         eType = OGR_GT_SetModifier(wkbMultiLineString, OGR_GT_HasZ(eType),
@@ -1379,9 +1277,9 @@ OGRLayer *OGROpenFileGDBDataSource::ICreateLayer(const char *pszLayerName,
         eType = OGR_GT_SetModifier(wkbMultiPolygon, OGR_GT_HasZ(eType),
                                    OGR_GT_HasM(eType));
 
-    auto poLayer = cpl::make_unique<OGROpenFileGDBLayer>(
+    auto poLayer = std::make_unique<OGROpenFileGDBLayer>(
         this, osFilename.c_str(), pszLayerName, eType, papszOptions);
-    if (!poLayer->Create(poSRS))
+    if (!poLayer->Create(poGeomFieldDefn))
         return nullptr;
     if (m_bInTransaction)
     {
@@ -1541,13 +1439,18 @@ OGRErr OGROpenFileGDBDataSource::DeleteLayer(int iLayer)
 /*                             FlushCache()                             */
 /************************************************************************/
 
-void OGROpenFileGDBDataSource::FlushCache(bool /*bAtClosing*/)
+CPLErr OGROpenFileGDBDataSource::FlushCache(bool /*bAtClosing*/)
 {
     if (eAccess != GA_Update)
-        return;
+        return CE_None;
 
+    CPLErr eErr = CE_None;
     for (auto &poLayer : m_apoLayers)
-        poLayer->SyncToDisk();
+    {
+        if (poLayer->SyncToDisk() != OGRERR_NONE)
+            eErr = CE_Failure;
+    }
+    return eErr;
 }
 
 /************************************************************************/
@@ -1557,7 +1460,7 @@ void OGROpenFileGDBDataSource::FlushCache(bool /*bAtClosing*/)
 bool OGROpenFileGDBDataSource::AddFieldDomain(
     std::unique_ptr<OGRFieldDomain> &&domain, std::string &failureReason)
 {
-    const auto domainName = domain->GetName();
+    const std::string domainName(domain->GetName());
     if (eAccess != GA_Update)
     {
         CPLError(CE_Failure, CPLE_NotSupported,
@@ -1737,7 +1640,7 @@ bool OGROpenFileGDBDataSource::DeleteFieldDomain(
 bool OGROpenFileGDBDataSource::UpdateFieldDomain(
     std::unique_ptr<OGRFieldDomain> &&domain, std::string &failureReason)
 {
-    const auto domainName = domain->GetName();
+    const std::string domainName(domain->GetName());
     if (eAccess != GA_Update)
     {
         CPLError(CE_Failure, CPLE_NotSupported,
@@ -1879,7 +1782,7 @@ bool OGROpenFileGDBDataSource::AddRelationship(
     std::unique_ptr<GDALRelationship> &&relationship,
     std::string &failureReason)
 {
-    const auto relationshipName = relationship->GetName();
+    const std::string relationshipName(relationship->GetName());
     if (eAccess != GA_Update)
     {
         CPLError(CE_Failure, CPLE_NotSupported,
@@ -1941,7 +1844,7 @@ bool OGROpenFileGDBDataSource::AddRelationship(
             CPLStringList aosOptions;
             aosOptions.SetNameValue("FID", "RID");
             OGRLayer *poMappingTable = ICreateLayer(
-                relationship->GetName().c_str(), nullptr, wkbNone, aosOptions);
+                relationship->GetName().c_str(), nullptr, aosOptions.List());
             if (!poMappingTable)
             {
                 failureReason = "Could not create mapping table " +
@@ -2157,7 +2060,7 @@ bool OGROpenFileGDBDataSource::UpdateRelationship(
     std::unique_ptr<GDALRelationship> &&relationship,
     std::string &failureReason)
 {
-    const auto relationshipName = relationship->GetName();
+    const std::string relationshipName(relationship->GetName());
     if (eAccess != GA_Update)
     {
         CPLError(CE_Failure, CPLE_NotSupported,
